@@ -1086,7 +1086,7 @@ class TranslationSolvers():
 
             all_results[i, :] = result.T
             all_trna_results[i, :] = trna_result
-            all_frapresults[i, :] = frapresult
+           # all_frapresults[i, :] = frapresult
             all_ribtimes[i, :] = ribtimes
             all_collisions[i, :] = coltimes
             all_nribs[i, :] = nribs[0]
@@ -1446,7 +1446,7 @@ class TranslationSolvers():
 
 
         N_rib = ssa_conditions['ribosome_preallocation']
-        all_results,all_nribs,all_collisions,all_frapresults,all_ribtimes,all_col_points = self.__generate_mats_lowmem(n_traj,k[0],t,N_rib,colors)
+        all_results,all_nribs,all_collisions,_,all_ribtimes,all_col_points = self.__generate_mats_lowmem(n_traj,k[0],t,N_rib,colors)
         footprint = ssa_conditions['footprint']
         evf = ssa_conditions['perturb'][0]
         evi = ssa_conditions['perturb'][1]
@@ -1457,18 +1457,18 @@ class TranslationSolvers():
 
         for i in range(n_traj):
 
-            result,ribtimes,frapresult,coltimes,colpointsx,colpointst = self.__generate_vecs_lowmem(k,t,N_rib,colors)
+            result,ribtimes,_,coltimes,colpointsx,colpointst = self.__generate_vecs_lowmem(k,t,N_rib,colors)
             nribs = np.array([0], dtype=np.int32)
 
 
             if i == 0: #detect any int64
-                inputs = [result, ribtimes, coltimes, colpointsx,colpointst, k[1:-1],frapresult, t, k[0], float(k[-1]), int(evf), int(evi), float(intime), seeds[i],nribs,x0,footprint, probe_vec ,int(colors), kon, koff, kprobe, probe_loc, flags,N_rib]
+                inputs = [result, ribtimes, coltimes, colpointsx,colpointst, k[1:-1], t, k[0], float(k[-1]), int(evf), int(evi), float(intime), seeds[i],nribs,x0,footprint, probe_vec ,int(colors), kon, koff, kprobe, probe_loc, flags,N_rib]
                 wash_inputs = self.__check_input_memview(inputs)
 
             if wash_inputs:
                 #check memview so all given variables are in int32 if integer for C
-                inputs = [result, ribtimes, coltimes, colpointsx,colpointst, k[1:-1],frapresult, t, k[0], float(k[-1]), int(evf), int(evi), float(intime), seeds[i],nribs,x0,footprint, probe_vec ,int(colors), kon, koff, kprobe, probe_loc, flags,N_rib]
-                result, ribtimes, coltimes, colpointsx,colpointst, kelong,frapresult, t, ki, kt, evf, evi, intime, seed,nribs,x0,footprint, probe_vec ,colors, kon, koff, kprobe, probe_loc, flags, N_rib = self.__check_memview(inputs)
+                inputs = [result, ribtimes, coltimes, colpointsx,colpointst, k[1:-1], t, k[0], float(k[-1]), int(evf), int(evi), float(intime), seeds[i],nribs,x0,footprint, probe_vec ,int(colors), kon, koff, kprobe, probe_loc, flags,N_rib]
+                result, ribtimes, coltimes, colpointsx,colpointst, kelong, t, ki, kt, evf, evi, intime, seed,nribs,x0,footprint, probe_vec ,colors, kon, koff, kprobe, probe_loc, flags, N_rib = self.__check_memview(inputs)
             else:
                 kelong = k[1:-1]
                 ki = k[0]
@@ -1479,11 +1479,11 @@ class TranslationSolvers():
                 seed = seeds[i]
                 colors = int(colors)
            
-            ssa_translation_lowmem.run_SSA(result, ribtimes, coltimes, colpointsx,colpointst, kelong,frapresult, t, ki, kt, evf, evi, intime, seed,nribs,x0,footprint, probe_vec ,colors, kon, koff, kprobe, probe_loc, flags, N_rib)
+            ssa_translation_lowmem.run_SSA(result, ribtimes, coltimes, colpointsx,colpointst, kelong, t, ki, kt, evf, evi, intime, seed,nribs,x0,footprint, probe_vec ,colors, kon, koff, kprobe, probe_loc, flags, N_rib)
             #ssa_translation.run_SSA(result, ribtimes, coltimes, k[1:-1],frapresult, truetime, k[0], k[-1], evf, evi, intime, seeds[i],nribs)
 
             all_results[i, :, :] = result.T
-            all_frapresults[i, :] = frapresult
+            #all_frapresults[i, :] = frapresult
             all_ribtimes[i, :] = ribtimes
             all_collisions[i, :] = coltimes
             all_nribs[i, :] = nribs
@@ -1619,7 +1619,7 @@ class TranslationSolvers():
 
 
         N_rib = ssa_conditions['ribosome_preallocation']
-        all_results,all_nribs,all_collisions,all_frapresults,all_ribtimes,all_col_points = self.__generate_mats_lowmem(n_traj,k[0],t,N_rib,colors)
+        all_results,all_nribs,all_collisions,_,all_ribtimes,all_col_points = self.__generate_mats_lowmem(n_traj,k[0],t,N_rib,colors)
         all_rib_loc = np.zeros((n_traj, len(t), N_rib), dtype=np.int32)
 
 
@@ -1634,16 +1634,16 @@ class TranslationSolvers():
         for i in range(n_traj):
 
             nribs = np.array([0], dtype=np.int32)
-            result,ribtimes,frapresult,coltimes,colpointsx,colpointst = self.__generate_vecs_lowmem(k,t,N_rib,colors)
+            result,ribtimes,_,coltimes,colpointsx,colpointst = self.__generate_vecs_lowmem(k,t,N_rib,colors)
             ribloc = np.zeros((N_rib,len(t)), dtype=np.int32)
             if i == 0: #detect any int64
-                inputs = [ribloc,result, ribtimes, coltimes, colpointsx,colpointst, k[1:-1], frapresult, t, k[0], float(k[-1]), int(evf), int(evi), float(intime), seeds[i],nribs,x0,footprint, probe_vec ,int(colors), kon, koff, kprobe, probe_loc, flags,N_rib]
+                inputs = [ribloc,result, ribtimes, coltimes, colpointsx,colpointst, k[1:-1], t, k[0], float(k[-1]), int(evf), int(evi), float(intime), seeds[i],nribs,x0,footprint, probe_vec ,int(colors), kon, koff, kprobe, probe_loc, flags,N_rib]
                 wash_inputs = self.__check_input_memview(inputs)
 
             if wash_inputs:
                 #check memview so all given variables are in int32 if integer for C
-                inputs = [ribloc,result, ribtimes, coltimes, colpointsx,colpointst, k[1:-1], frapresult, t, k[0], float(k[-1]), int(evf), int(evi), float(intime), seeds[i],nribs,x0,footprint, probe_vec ,int(colors), kon, koff, kprobe, probe_loc, flags,N_rib]
-                ribloc,result, ribtimes, coltimes, colpointsx,colpointst, kelong,frapresult, t, ki, kt, evf, evi, intime, seed,nribs,x0,footprint, probe_vec ,colors, kon, koff, kprobe, probe_loc, flags, N_rib = self.__check_memview(inputs)
+                inputs = [ribloc,result, ribtimes, coltimes, colpointsx,colpointst, k[1:-1], t, k[0], float(k[-1]), int(evf), int(evi), float(intime), seeds[i],nribs,x0,footprint, probe_vec ,int(colors), kon, koff, kprobe, probe_loc, flags,N_rib]
+                ribloc,result, ribtimes, coltimes, colpointsx,colpointst, kelong, t, ki, kt, evf, evi, intime, seed,nribs,x0,footprint, probe_vec ,colors, kon, koff, kprobe, probe_loc, flags, N_rib = self.__check_memview(inputs)
             else:
                 kelong = k[1:-1]
                 ki = k[0]
@@ -1655,11 +1655,11 @@ class TranslationSolvers():
                 colors = int(colors)
 
             
-            ssa_translation_lowmem.run_SSA_full(ribloc, result, ribtimes, coltimes, colpointsx,colpointst, kelong,frapresult, t, ki, kt, evf, evi, intime, seed,nribs,x0,footprint, probe_vec ,colors, kon, koff, kprobe, probe_loc, flags)
+            ssa_translation_lowmem.run_SSA_full(ribloc, result, ribtimes, coltimes, colpointsx,colpointst, kelong, t, ki, kt, evf, evi, intime, seed,nribs,x0,footprint, probe_vec ,colors, kon, koff, kprobe, probe_loc, flags)
             #ssa_translation.run_SSA(result, ribtimes, coltimes, k[1:-1],frapresult, truetime, k[0], k[-1], evf, evi, intime, seeds[i],nribs)
 
             all_results[i, :, :] = result.T
-            all_frapresults[i, :] = frapresult
+            #all_frapresults[i, :] = frapresult
             all_ribtimes[i, :] = ribtimes
             all_collisions[i, :] = coltimes
             all_nribs[i, :] = nribs
